---
name: Bug report
about: Create a report to help us improve CV-CUDA
title: "[BUG]"
labels: "? - Needs Triage, bug"
assignees: ''

---

**Describe the bug**
A clear and concise description of the bug.

**Steps/Code to reproduce bug**
Follow this guide
http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports to craft a
minimal bug report. This helps us reproduce the issue you're having and resolve
the issue more quickly.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment overview (please complete the following information)**
 - Environment location: [Bare-metal, Docker, Cloud(specify cloud provider)]
 - Method of cuDF install: [Docker, pip, or from source]
   - If method of install is [Docker], provide `docker pull` & `docker run` commands used

**Environment details**
Please run and paste the output of the `cvcuda/print_env.sh` script here, to gather any other relevant environment details

**Additional context**
Add any other context about the problem here.
